@@ -1,4 +1,6 @@
 from .vault import *
 from .keys import *
 from .register import *
-from .deployment import *
\ No newline at end of file
+from .deployment import *
+from .update import *
+from .kubebench import *
\ No newline at end of file
